@@ -69,8 +69,9 @@ class BaseStrategy:
                         self.index_labels.append(id)
             affected_partitions += 1
             num_ids = list(map(self.index_labels.index, ids))
-            self.partitions[partition_num].add_items(items, num_ids)
-            self.schema.add_mapping(partition_num, num_ids, [d for d in data if d[self.schema.id_col] in ids])
+            self.partitions[strategy_id][partition_num].add_items(items, num_ids)
+            if strategy_id == self.schema.base_strategy_id():
+                self.schema.add_mapping(partition_num, num_ids, [d for d in data if d['id'] in ids])
         return errors, affected_partitions
 
     def index_dataframe(self, df, parallel=True, strategy_id=None):
@@ -101,9 +102,9 @@ class BaseStrategy:
             encoded = dict(Parallel(n_jobs=-1)(tup_encode(partition, data, strategy_id) for partition, data in partitioned.items()))
 
             @delayed
-            def add_items_to_partition(vecs, partition_num, from_, to_):
+            def add_items_to_partition(vecs, partition_num, strategy_id, from_, to_):
                 ids = np.arange(from_, to_)
-                self.partitions[partition_num].add_items(vecs, ids)
+                self.partitions[strategy_id][partition_num].add_items(vecs, ids)
             
             Parallel(n_jobs=-1, require='sharedmem')([add_items_to_partition(data, partition_nums[partition], strategy_id, num_ids[partition][0], num_ids[partition][1]) for partition, data in encoded.items()])
         else:
@@ -111,7 +112,7 @@ class BaseStrategy:
                 partition_num = partition_nums[partition]
                 from_, to_ = num_ids[partition]
                 ids = list(range(from_, to_))
-                self.partitions[partition_num].add_items(vecs, ids)
+                self.partitions[strategy_id][partition_num].add_items(vecs, ids)
         return affected_partitions
 
     def query_by_partition_and_vector(self, partition_num, strategy_id, vec, k, explain=False):
@@ -135,7 +136,7 @@ class BaseStrategy:
         vec = vec.reshape(-1)
         explanation = []
         # X = self.partitions[partition_num].get_items(num_ids[0])
-        X = np.array([self.schema.restore_vector_with_index(partition_num, index, strategy_id) for index in num_ids[0]], dtype='float32')
+        X = np.array([self.schema.restore_vector_with_index(partition_num, index, strategy_id) for index in num_ids], dtype='float32')
         first_sim = None
         for ret_vec in X:
             start = 0
@@ -145,8 +146,8 @@ class BaseStrategy:
                     explanation[-1][col] = 0  # float(enc.column_weight)
                     continue
                 end = start + len(enc)
-                ret_part = ret_vec[start:end]
-                query_part =   vec[start:end]
+                ret_part = ret_vec[0][start:end]
+                query_part = vec[start:end]
                 if self.schema.metric == 'l2':
                     # The returned distance from the similarity server is not squared
                     dst = ((ret_part-query_part)**2).sum()
@@ -183,9 +184,10 @@ class BaseStrategy:
             l, d, e = self.query_by_partition_and_vector(partition_num, strategy_id, vec, k, explain)
             labels.extend(l)
             distances.extend(d)
+            explanation.extend(e)
             #TODO: explanation is not supported when having multiple filters
         labels, distances = zip(*sorted(zip(labels, distances), key=at(1)))
-        return labels, distances ,explanation
+        return labels, distances, explanation
 
 
 
